@@ -4,8 +4,17 @@ from .hosterino import checkAnswers
 from .Utils.utils import waitForApproval, approved, postDelay, randomColor
 from .Loader.loader import getRound
 from sty import fg
+from importlib.metadata import version
+from update_checker import UpdateChecker
 import time
 
+v = version('botterino')
+checker = UpdateChecker()
+result = checker.check('botterino', v)
+if result:
+    print(f'{fg.yellow}{result}')
+    print(f'{fg.yellow}run pip install --upgrade botterino to update')
+
 def checkType(r):
     if 'tolerance' in r and 'answer' in r:
         return "automatic"
